% Inventory 27-May-2019 

% Read raw conc data (TN & TDN) from all yearly NBC files; convert to mg/L.
%   Remove pre-5/1/2006 data (some sparse late-2005 values), so that
%   downstream calcs don't fill several months by interpolation.
% Read raw flow data (my matfile), apply ungauged scalefac, convert to MGD.
% Save one mat file per river.

% Note: This code does not use censored values. None are present, for the
%   the stations of interest, up through 2017. Any future modification of 
%   the code should not assume this is true.

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

readme = {'Cdn: datenum for TN, TDN; TN, TDN: conc [mg/L];         ';...
          'Qdn: datenum for flow; Q: flow (ungauged upscaled) [MGD]';};

%% load rivers (all rivers)
eval(sprintf('rivdat = load(''%s'');',[q.indir q.infil]));

%% main loop
for iriv = 1:length(nams)
    %% CONCENTRATION DATA
    fprintf('%s (%d of %d)\n',nams{iriv},iriv,length(nams));    
    dn = [];
    TDN = [];
    TN = [];
    for iyr = 1:length(c.yrs)
        fprintf('   Year %d (%d of %d)\n',c.yrs(iyr),iyr,length(c.yrs));
        fprintf('      reading entire file\n');
        [~,~,raw] = xlsread([c.indir num2str(c.yrs(iyr)) c.infilstem],...
            num2str(c.yrs(iyr)));
        % keep only the dates, stations, tdn, and tn columns
        raw = raw(:,[1 4 16 17]);
        % strip off col headers
        raw = raw(2:end,:);
        fprintf('      keeping only current station\n');
        raw = raw(find(cellfun(@(X) strcmp(X,c.stns{iriv}) | ...
            strcmp(X,[c.stns{iriv} ' (Duplicate)']), raw(:,2))),...
                        [1 3 4]);
         % handle case where part of spreadsheet column formatted as string 
        ind = find(cellfun(@ischar,raw(:,2)));
        if length(ind)
            raw(ind,2) = mat2cell(cellfun(@str2double,raw(ind,2)),...
                ones(length(ind),1),1);
        end
        ind = find(cellfun(@ischar,raw(:,3)));
        if length(ind)
             raw(ind,3) = mat2cell(cellfun(@str2double,raw(ind,3)),...
                 ones(length(ind),1),1);
        end
        % extract numeric values from cell
        TNtmp = cell2mat(raw(:,2));
        TDNtmp = cell2mat(raw(:,3));
        dntmp = cellfun(@datenum,raw(:,1));
        clear raw;
        % avg when multiple values (e.g. duplicates), append to dn/TN/TDN
        unqdn = unique(dntmp);
        for i = 1:length(unqdn)
            ind = find(dntmp==unqdn(i));
            dn = [dn; unqdn(i);];
            TN = [TN; nanmean(TNtmp(ind));];
            TDN = [TDN; nanmean(TDNtmp(ind));]; 
            clear ind;
        end
        clear unqdn i dntmp TNtmp TDNtmp;
    end
    clear iyr;
    % remove any that have dn=nan, or both TDN & TN are nan
    ind = find(isnan(dn) | (isnan(TN) & isnan(TDN)));
    dn(ind) = [];
    TN(ind) = [];
    TN = TN/1000;      % convert to mg/L
    TDN(ind) = [];
    TDN = TDN/1000;    % convert to mg/L
    clear ind;
    Cdn = dn;
    clear dn;
    % remove any with NaN for dn
    TN(isnan(Cdn)) = [];
    TDN(isnan(Cdn)) = [];
    Cdn(isnan(Cdn)) = [];
    % remove any earlier than May 2006
    %       some late 2005 value exist but discard them to avoid 
    %       interpolating across several early months of 2006
    whr = find(Cdn<datenum(2006,5,1));
    TN(whr) = [];
    TDN(whr) = [];
    Cdn(whr) = [];
    % FLOW
    ind = find(ismember(rivdat.rivnam,q.rivnam(iriv)));
    Qdn = rivdat.dn';
    Q = (rivdat.m3persec(ind,:)')*q.ungaugedfac(iriv)/0.043813; % to MGD
    clear ind;
    ind = find(Qdn>=datenum(2001,1,1) & Qdn<=datenum(2017,12,31));
    Qdn = Qdn(ind);
    Q = Q(ind);
    clear ind;
    % Save
    eval(sprintf('save dat/%s Cdn Qdn TN TDN Q readme;',nams{iriv}));
end

% end of module
diary off;