% Inventory 31-May-2019 

% Create mat file with useful subset of spreadsheet data 
%   Flow: Q(avg&max)     [MGD] 
%   Concs [mg/l]:   TN NH4 NO2 NO3 TKN (all avg&max) / NO32 (max only)
%   TN-Load(avg)         [lb/d]

% also plot that graphically show presence/absence:
%       the date ranges and frequencies, for each species

% no outlier removal
% values reported as <X are retained as X (substitution of the MDL)

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

ddn = datenum(2001,1,1):datenum(2017,12,31);
Qflow = nan*ones(size(ddn));
tkn = Qflow;
no3 = Qflow;
no2 = Qflow;
nh4 = Qflow;

yrs = 2001:2017;
for iyr = 1:length(yrs)
    for mon = 1:12
        fprintf('reading year %d month %d\n',yrs(iyr),mon);
        [~,~,raw] = xlsread([indir sprintf('%d-%02d.xls',yrs(iyr),mon)]);
        dn = cellfun(@datenum,raw(:,2));
        dnind = find(~isnan(dn));
        dn = dn(dnind);
        q = cellfun(@abs,raw(dnind,3));
        nutnam = {'TKN';'NO3';'NO2';'NH4';};
        for inut = 1:length(nutnam)
            eval(sprintf('%s = nan*ones(size(q));',nutnam{inut}));
            % TKN
            colind = find(strcmp(raw(5,:)',[nutnam{inut} '-EFF']));
            if isempty(colind)
                fprintf('did not find %s-EFF header\n',nutnam{inut});
                keyboard;
            end
            nind = find(cellfun(@isstr,raw(dnind,colind)));
            strs = raw(dnind(nind),colind);
            clear colind;
            dat = nan*ones(size(strs));
            for i = 1:length(strs)
                str = strs{i};
                if str(1) == '<'
                    str = str(2:end); % using replacement of NDs
                elseif isempty(str2double(str(1)))
                    fprintf('non-< pre-character found: %s\n',str(1));
                    keyboard;
                end
                dat(i) = str2double(str);
                clear str;
            end
            clear i strs;
            eval(sprintf('%s(nind) = dat;',nutnam{inut}));
            clear nind dat;
        end
        clear raw inut nutnam dnind;
        ind = nan*ones(size(dn));
        for i = 1:length(dn)
            ind(i) = find(ddn==dn(i));
        end
        clear i dn;
        Qflow(ind) = q;
        tkn(ind) = TKN;
        no3(ind) = NO3;
        no2(ind) = NO2;
        nh4(ind) = NH4;
        clear q TKN NO3 NO2 NH4 ind;
    end
    clear mon;
    
    figland('on');
    subplot(5,1,1);
    plot(ddn,Qflow,'k.-');
    datetick;
    ylabel('Q');
    subplot(5,1,2);
    plot(ddn,tkn,'k.-');
    datetick;
    ylabel('TKN');
    subplot(5,1,3);
    plot(ddn,no3,'k.-');
    datetick;
    ylabel('NO3');
    subplot(5,1,4);
    plot(ddn,no2,'k.-');
    datetick;
    ylabel('NO2');
    subplot(5,1,5);
    plot(ddn,nh4,'k.-');
    datetick;
    ylabel('NH4');
    pause(1);
    if iyr < 17 
        delete(gcf);
    end
end
clear yrs iyr;

TKN = tkn;
NO3 = no3;
NO2 = no2;
NH4 = nh4;
clear tkn no3 no2 nh4;

readme = 'ddn: daily datenum; Qflow: flow [MGD]; TKN/NO3/NO2/NH4: [mg/L]';
save dat/FallRiver ddn Qflow TKN NO3 NO2 NH4 readme;

print -dpng plt/plot;

delete(gcf);
    



% end of module
diary off;